@@ -103,11 +103,10 @@ GetOptions ('help' => \$bHelp,
 ####################################################################################################################################
 eval
 {
-
     # Display version and exit if requested
     if ($bHelp || $bVersion)
     {
-        print BACKREST_NAME . ' ' . $VERSION . " Documentation Builder\n";
+        print BACKREST_NAME . ' ' . BACKREST_VERSION . " Documentation Builder\n";
 
         if ($bHelp)
         {
@@ -132,17 +131,8 @@ eval
         !$bNoExe
             or confess "--no-exe ${strError}";
 
-        !$bNoCache
-            or confess "--no-cache ${strError}";
-
         !@stryRequire
             or confess "--require ${strError}";
-
-        !@stryOutput
-            or confess "--out ${strError}";
-
-        !@stryExclude
-            or confess "--exclude ${strError}";
     }
 
     # Set console log level
@@ -177,8 +167,8 @@ eval
     }
 
     # Load the manifest
-    my $oManifest =
-        new BackRestDoc::Common::DocManifest(\@stryKeyword, \@stryRequire, \@stryExclude, $oVariableOverride, $strDocPath, $bDeploy, $bCacheOnly);
+    my $oManifest = new BackRestDoc::Common::DocManifest(
+        \@stryKeyword, \@stryRequire, \@stryExclude, $oVariableOverride, $strDocPath, $bDeploy, $bCacheOnly);
 
     if (!$bNoCache)
     {
