@@ -24,6 +24,7 @@ use pgBackRest::Version;
 use lib dirname($0) . '/../test/lib';
 use pgBackRestTest::Common::ExecuteTest;
 use pgBackRestTest::Common::HostTest;
+use pgBackRestTest::Common::HostGroupTest;
 
 use BackRestDoc::Common::DocManifest;
 
@@ -115,6 +116,11 @@ sub executeKey
         output => JSON::PP::false,
     };
 
+    if (defined($oCommand->fieldGet('exe-cmd-extra', false)))
+    {
+        $$hCacheKey{'cmd-extra'} = $oCommand->fieldGet('exe-cmd-extra');
+    }
+
     if (defined($oCommand->paramGet('err-expect', false)))
     {
         $$hCacheKey{'err-expect'} = $oCommand->paramGet('err-expect');
@@ -211,10 +217,11 @@ sub execute
                     confess &log(ERROR, "cannot execute on host ${strHostName} because the host does not exist");
                 }
 
-                my $oExec = $oHost->execute($strCommand,
-                                            {iExpectedExitStatus => $$hCacheKey{'err-expect'},
-                                             bSuppressError => $oCommand->paramTest('err-suppress', 'y'),
-                                             iRetrySeconds => $oCommand->paramGet('retry', false)});
+                my $oExec = $oHost->execute(
+                    $strCommand . (defined($$hCacheKey{'cmd-extra'}) ? ' ' . $$hCacheKey{'cmd-extra'} : ''),
+                    {iExpectedExitStatus => $$hCacheKey{'err-expect'},
+                     bSuppressError => $oCommand->paramTest('err-suppress', 'y'),
+                     iRetrySeconds => $oCommand->paramGet('retry', false)});
                 $oExec->begin();
                 $oExec->end();
 
@@ -567,7 +574,7 @@ sub backrestConfig
 
             $oHost->copyTo($strLocalFile, $$hCacheKey{file}, $oConfig->paramGet('owner', false, 'postgres:postgres'), '640');
 
-            my $strConfig = fileStringRead($strLocalFile);
+            $strConfig = fileStringRead($strLocalFile);
             my @stryConfig = undef;
 
             if (trim($strConfig) ne '')
@@ -945,9 +952,12 @@ sub sectionChildProcess
                     confess &log(ERROR, 'cannot add host ${strName} because the host already exists');
                 }
 
-                my $oHost =
-                    new pgBackRestTest::Common::HostTest(
-                        $$hCacheKey{name}, $$hCacheKey{image}, $$hCacheKey{user}, $$hCacheKey{os}, $$hCacheKey{mount});
+                executeTest("rm -rf ~/data/$$hCacheKey{name}");
+                executeTest("mkdir -p ~/data/$$hCacheKey{name}/etc");
+
+                my $oHost = new pgBackRestTest::Common::HostTest(
+                    $$hCacheKey{name}, "doc-$$hCacheKey{name}", $$hCacheKey{image}, $$hCacheKey{user}, $$hCacheKey{os},
+                    [$$hCacheKey{mount}]);
 
                 $self->{host}{$$hCacheKey{name}} = $oHost;
                 $self->{oManifest}->variableSet("host-$$hCacheKey{name}-ip", $oHost->{strIP}, true);
@@ -959,30 +969,9 @@ sub sectionChildProcess
                     $self->execute($oSection, $$hCacheKey{name}, $oExecute, $iDepth + 1, false);
                 }
 
-                $oHost->executeSimple("sh -c 'echo \"\" >> /etc/hosts\'", undef, 'root');
-                $oHost->executeSimple("sh -c 'echo \"# Test Hosts\" >> /etc/hosts'", undef, 'root');
-
-                # Add all other host IPs to this host
-                foreach my $strOtherHostName (sort(keys(%{$self->{host}})))
-                {
-                    if ($strOtherHostName ne $$hCacheKey{name})
-                    {
-                        my $oOtherHost = $self->{host}{$strOtherHostName};
-
-                        $oHost->executeSimple("sh -c 'echo \"$oOtherHost->{strIP} ${strOtherHostName}\" >> /etc/hosts'", undef, 'root');
-                    }
-                }
-
-                # Add this host IP to all other hosts
-                foreach my $strOtherHostName (sort(keys(%{$self->{host}})))
-                {
-                    if ($strOtherHostName ne $$hCacheKey{name})
-                    {
-                        my $oOtherHost = $self->{host}{$strOtherHostName};
-
-                        $oOtherHost->executeSimple("sh -c 'echo \"$oHost->{strIP} $$hCacheKey{name}\" >> /etc/hosts'", undef, 'root');
-                    }
-                }
+                # Add to the host group
+                my $oHostGroup = hostGroupGet();
+                $oHostGroup->hostAdd($oHost);
 
                 $self->cachePush($strCacheType, $hCacheKey, $hCacheValue);
             }
