@@ -361,7 +361,22 @@ sub sectionProcess
 
             if (!defined($oDescription))
             {
-                confess &log(ERROR, "unable to find ${strOption} option in sections - try adding command?");
+                confess &log(ERROR, "unable to find ${strOption} option in sections - try adding option?");
+            }
+
+            $oSectionBodyElement->
+                addNew(HTML_DIV, 'section-body-text',
+                       {strContent => $self->processText($oDescription)});
+        }
+        # Add cmd descriptive text
+        elsif ($oChild->nameGet() eq 'cmd-description')
+        {
+            my $strCommand = $oChild->paramGet("key");
+            my $oDescription = ${$self->{oReference}->{oConfigHash}}{&CONFIG_HELP_COMMAND}{$strCommand}{&CONFIG_HELP_DESCRIPTION};
+
+            if (!defined($oDescription))
+            {
+                confess &log(ERROR, "unable to find ${strCommand} command in sections - try adding command?");
             }
 
             $oSectionBodyElement->
