@@ -11,6 +11,7 @@ use Exporter qw(import);
     our @EXPORT = qw();
 use Fcntl qw(SEEK_CUR O_RDONLY O_WRONLY O_CREAT);
 use File::Basename qw(dirname basename);
+use Scalar::Util qw(blessed);
 
 use lib dirname($0);
 use pgBackRest::Common::Exception;
@@ -30,6 +31,8 @@ use pgBackRest::FileCommon;
 use constant OP_ARCHIVE                                             => 'Archive';
 
 use constant OP_ARCHIVE_GET                                         => OP_ARCHIVE . '->get';
+use constant OP_ARCHIVE_GET_ARCHIVE_ID                              => OP_ARCHIVE . '->getArchiveId';
+    push @EXPORT, qw(OP_ARCHIVE_GET_ARCHIVE_ID);
 use constant OP_ARCHIVE_GET_CHECK                                   => OP_ARCHIVE . '->getCheck';
     push @EXPORT, qw(OP_ARCHIVE_GET_CHECK);
 use constant OP_ARCHIVE_GET_PROCESS                                 => OP_ARCHIVE . '->getProcess';
@@ -57,7 +60,7 @@ my $oWalMagicHash =
     hex('0xD075') => PG_VERSION_93,
     hex('0xD07E') => PG_VERSION_94,
     hex('0xD087') => PG_VERSION_95,
-    hex('0xD091') => PG_VERSION_96,
+    hex('0xD093') => PG_VERSION_96,
 };
 
 ####################################################################################################################################
@@ -212,30 +215,48 @@ sub walFileName
 
     # Record the start time
     my $oWait = waitInit($iWaitSeconds);
-
-    # Determine the path where the requested WAL segment is located
-    my $strArchivePath = dirname($oFile->pathGet(PATH_BACKUP_ARCHIVE, "$strArchiveId/${strWalSegment}"));
     my @stryWalFileName;
+    my $bNoTimeline = $strWalSegment =~ /^[0-F]{16}$/ ? true : false;
 
     do
     {
-        # Get the name of the requested WAL segment (may have hash info and compression extension)
-        @stryWalFileName = $oFile->list(PATH_BACKUP_ABSOLUTE, $strArchivePath,
-            "^${strWalSegment}" . ($bPartial ? '\\.partial' : '') .
-            "(-[0-f]+){0,1}(\\.$oFile->{strCompressExtension}){0,1}\$", undef, true);
+        # If the timeline is on the WAL segment then use it, otherwise contruct a regexp with the major WAL part to find paths
+        # where the wal could be found.
+        my @stryTimelineMajor = ('default');
 
-        # If there is more than one matching archive file then there is a serious issue - likely a bug in the archiver
-        if (@stryWalFileName > 1)
+        if ($bNoTimeline)
         {
-            confess &log(ASSERT, @stryWalFileName . " duplicate files found for ${strWalSegment}", ERROR_ARCHIVE_DUPLICATE);
+            @stryTimelineMajor =
+                $oFile->list(PATH_BACKUP_ARCHIVE, $strArchiveId, '[0-F]{8}' . substr($strWalSegment, 0, 8), undef, true);
+        }
+
+        foreach my $strTimelineMajor (@stryTimelineMajor)
+        {
+            my $strWalSegmentFind = $bNoTimeline ? $strTimelineMajor . substr($strWalSegment, 8, 8) : $strWalSegment;
+
+            # Determine the path where the requested WAL segment is located
+            my $strArchivePath = dirname($oFile->pathGet(PATH_BACKUP_ARCHIVE, "$strArchiveId/${strWalSegmentFind}"));
+
+            # Get the name of the requested WAL segment (may have hash info and compression extension)
+            push(@stryWalFileName, $oFile->list(
+                PATH_BACKUP_ABSOLUTE, $strArchivePath,
+                "^${strWalSegmentFind}" . ($bPartial ? '\\.partial' : '') .
+                    "(-[0-f]+){0,1}(\\.$oFile->{strCompressExtension}){0,1}\$",
+                undef, true));
         }
     }
     while (@stryWalFileName == 0 && waitMore($oWait));
 
+    # If there is more than one matching archive file then there is a serious issue - likely a bug in the archiver
+    if (@stryWalFileName > 1)
+    {
+        confess &log(ASSERT, @stryWalFileName . " duplicate files found for ${strWalSegment}", ERROR_ARCHIVE_DUPLICATE);
+    }
+
     # If waiting and no WAL segment was found then throw an error
     if (@stryWalFileName == 0 && defined($iWaitSeconds))
     {
-        confess &log(ERROR, "could not find WAL segment ${strWalSegment} after " . waitInterval($oWait)  . ' second(s)');
+        confess &log(ERROR, "could not find WAL segment ${strWalSegment} after ${iWaitSeconds} second(s)", ERROR_ARCHIVE_TIMEOUT);
     }
 
     # Return from function and log return values if any
@@ -421,6 +442,69 @@ sub get
 # getCheck
 ####################################################################################################################################
 sub getCheck
+{
+    my $self = shift;
+
+    # Assign function parameters, defaults, and log debug info
+    my
+    (
+        $strOperation,
+        $oFile,
+        $strDbVersion,
+        $ullDbSysId
+    ) =
+        logDebugParam
+    (
+        OP_ARCHIVE_GET_CHECK, \@_,
+        {name => 'oFile'},
+        {name => 'strDbVersion', required => false},
+        {name => 'ullDbSysId', required => false}
+    );
+
+    my $strArchiveId;
+
+    # If the dbVersion/dbSysId are not passed, then we need to retrieve the database information
+    if (!defined($strDbVersion) || !defined($ullDbSysId) )
+    {
+        # get DB info for comparison
+        ($strDbVersion, my $iControlVersion, my $iCatalogVersion, $ullDbSysId) =
+            (new pgBackRest::Db())->info($oFile, optionGet(OPTION_DB_PATH));
+    }
+
+    if ($oFile->isRemote(PATH_BACKUP_ARCHIVE))
+    {
+        # Build param hash
+        my %oParamHash;
+
+        # Pass the database information to the remote server
+        $oParamHash{'db-version'} = $strDbVersion;
+        $oParamHash{'db-sys-id'} = $ullDbSysId;
+
+        $strArchiveId = $oFile->{oProtocol}->cmdExecute(OP_ARCHIVE_GET_CHECK, \%oParamHash, true);
+    }
+    else
+    {
+        # check that the archive info is compatible with the database and create the file if it does not exist
+        $strArchiveId =
+            (new pgBackRest::ArchiveInfo($oFile->pathGet(PATH_BACKUP_ARCHIVE), true))->check($strDbVersion, $ullDbSysId);
+    }
+
+    # Return from function and log return values if any
+    return logDebugReturn
+    (
+        $strOperation,
+        {name => 'strArchiveId', value => $strArchiveId, trace => true}
+    );
+}
+
+####################################################################################################################################
+# getArchiveId
+#
+# CAUTION: Only to be used by commands where the DB Version and DB System ID are not important such that the
+# db-path is not valid for the command  (i.e. Expire command). Since this function will not check validity of the database version
+# call getCheck function instead.
+####################################################################################################################################
+sub getArchiveId
 {
     my $self = shift;
     my $oFile = shift;
@@ -432,14 +516,14 @@ sub getCheck
     ) =
         logDebugParam
     (
-        OP_ARCHIVE_GET_CHECK
+        OP_ARCHIVE_GET_ARCHIVE_ID
     );
 
     my $strArchiveId;
 
     if ($oFile->isRemote(PATH_BACKUP_ARCHIVE))
     {
-        $strArchiveId = $oFile->{oProtocol}->cmdExecute(OP_ARCHIVE_GET_CHECK, undef, true);
+        $strArchiveId = $oFile->{oProtocol}->cmdExecute(OP_ARCHIVE_GET_ARCHIVE_ID, undef, true);
     }
     else
     {
@@ -511,7 +595,7 @@ sub pushProcess
 
         $self->push($ARGV[1], $bArchiveAsync);
 
-        # Fork is async archiving is enabled
+        # Fork if async archiving is enabled
         if ($bArchiveAsync)
         {
             # Fork and disable the async archive flag if this is the parent process
@@ -734,7 +818,7 @@ sub pushCheck
         # Create the archive path if it does not exist
         $oFile->pathCreate(PATH_BACKUP_ARCHIVE, undef, undef, true, true);
 
-        # If the info file exists check db version and system-id
+        # If the info file exists check db version and system-id, else create it with the db version and system-id passed and the history
         $strArchiveId = (new pgBackRest::ArchiveInfo($oFile->pathGet(PATH_BACKUP_ARCHIVE)))->check($strDbVersion, $ullDbSysId);
 
         # Check if the WAL segment already exists in the archive
@@ -993,24 +1077,20 @@ sub range
             {name => 'bSkipFF', default => false}
         );
 
-    # Get the timelines and make sure they match
-    my $strTimeline = substr($strArchiveStart, 0, 8);
+    # Working variables
     my @stryArchive;
     my $iArchiveIdx = 0;
 
-    if ($strTimeline ne substr($strArchiveStop, 0, 8))
-    {
-        confess &log(ERROR, "timelines differ between ${strArchiveStart} and ${strArchiveStop}");
-    }
-
     # Iterate through all archive logs between start and stop
-    my $iStartMajor = hex substr($strArchiveStart, 8, 8);
-    my $iStartMinor = hex substr($strArchiveStart, 16, 8);
+    my @stryArchiveSplit = split('/', $strArchiveStart);
+    my $iStartMajor = hex($stryArchiveSplit[0]);
+    my $iStartMinor = hex(substr(sprintf("%08s", $stryArchiveSplit[1]), 0, 2));
 
-    my $iStopMajor = hex substr($strArchiveStop, 8, 8);
-    my $iStopMinor = hex substr($strArchiveStop, 16, 8);
+    @stryArchiveSplit = split('/', $strArchiveStop);
+    my $iStopMajor = hex($stryArchiveSplit[0]);
+    my $iStopMinor = hex(substr(sprintf("%08s", $stryArchiveSplit[1]), 0, 2));
 
-    $stryArchive[$iArchiveIdx] = uc(sprintf("${strTimeline}%08x%08x", $iStartMajor, $iStartMinor));
+    $stryArchive[$iArchiveIdx] = uc(sprintf("%08x%08x", $iStartMajor, $iStartMinor));
     $iArchiveIdx += 1;
 
     while (!($iStartMajor == $iStopMajor && $iStartMinor == $iStopMinor))
@@ -1023,7 +1103,7 @@ sub range
             $iStartMinor = 0;
         }
 
-        $stryArchive[$iArchiveIdx] = uc(sprintf("${strTimeline}%08x%08x", $iStartMajor, $iStartMinor));
+        $stryArchive[$iArchiveIdx] = uc(sprintf("%08x%08x", $iStartMajor, $iStartMinor));
         $iArchiveIdx += 1;
     }
 
@@ -1035,4 +1115,168 @@ sub range
     );
 }
 
+####################################################################################################################################
+# check
+#
+# Validates the database configuration and checks that the archive logs can be read by backup. This will alert the user to any
+# misconfiguration, particularly of archiving, that would result in the inability of a backup to complete (e.g waiting at the end
+# until it times out because it could not find the WAL file).
+####################################################################################################################################
+sub check
+{
+    my $self = shift;
+
+    # Assign function parameters, defaults, and log debug info
+    my $strOperation = logDebugParam(__PACKAGE__ . '->check');
+
+    # Initialize default file object
+    my $oFile = new pgBackRest::File
+    (
+        optionGet(OPTION_STANZA),
+        optionGet(OPTION_REPO_PATH),
+        optionRemoteType(),
+        protocolGet()
+    );
+
+    # Initialize the database object
+    my $oDb = new pgBackRest::Db();
+
+    # Validate the database configuration
+    $oDb->configValidate($oFile, optionGet(OPTION_DB_PATH));
+
+    # Force archiving
+    my $strWalSegment = $oDb->xlogSwitch();
+
+    # Get the timeout and error message to display - if it is 0 we are testing
+    my $iArchiveTimeout = optionGet(OPTION_ARCHIVE_TIMEOUT);
+
+    # Initialize the result variables
+    my $iResult = 0;
+    my $strResultMessage = undef;
+
+    # Record the start time to wait for the archive.info file to be written
+    my $oWait = waitInit($iArchiveTimeout);
+
+    my $strArchiveId = undef;
+    my $strArchiveFile = undef;
+    my $oBackupInfo = undef;
+
+    # Turn off console logging to control when to display the error
+    logLevelSet(undef, OFF);
+
+    # Wait for the archive.info to be written. If it does not get written within the timout period then report the last error.
+    do
+    {
+        eval
+        {
+            # check that the archive info file is written and is valid for the current database of the stanza
+            $strArchiveId = $self->getCheck($oFile);
+
+            # Clear any previous errors if we've found the archive.info
+            $iResult = 0;
+        };
+
+        if ($@)
+        {
+            my $oMessage = $@;
+
+            # If this is a backrest error then capture the last code and message else confess
+            if (blessed($oMessage) && $oMessage->isa('pgBackRest::Common::Exception'))
+            {
+                $iResult = $oMessage->code();
+                $strResultMessage = $oMessage->message();
+            }
+            else
+            {
+                confess $oMessage;
+            }
+        }
+    } while (!defined($strArchiveId) && waitMore($oWait));
+
+    # If able to get the archive id then check the archived WAL file with the time remaining
+    if ($iResult == 0)
+    {
+        eval
+        {
+            $strArchiveFile = $self->walFileName($oFile, $strArchiveId, $strWalSegment, false, $iArchiveTimeout);
+        };
+
+        # If this is a backrest error then capture the code and message else confess
+        if ($@)
+        {
+            my $oMessage = $@;
+
+            # If a backrest exception then return the code else confess
+            if (blessed($oMessage) && $oMessage->isa('pgBackRest::Common::Exception'))
+            {
+                $iResult = $oMessage->code();
+                $strResultMessage = $oMessage->message();
+            }
+            else
+            {
+                confess $oMessage;
+            }
+        }
+    }
+
+    # Reset the console logging
+    logLevelSet(undef, optionGet(OPTION_LOG_LEVEL_CONSOLE));
+
+    # If the archive info was successful, then check the backup info
+    if ($iResult == 0)
+    {
+        # If backup repo is local, then check the backup info
+        if (!optionRemoteTypeTest(BACKUP))
+        {
+            # Load or build backup.info
+            eval
+            {
+                $oBackupInfo = new pgBackRest::BackupInfo($oFile->pathGet(PATH_BACKUP_CLUSTER));
+            };
+            if ($@)
+            {
+                my $oMessage = $@;
+
+                # If this is a backrest error but it is not that the file is missing then confess
+                if (blessed($oMessage) && $oMessage->isa('pgBackRest::Common::Exception')
+                    && ($oMessage->code() != ERROR_PATH_MISSING))
+                {
+                    confess $oMessage;
+                }
+            }
+            else
+            {
+                # Get the current database info
+                my ($strDbVersion, $iControlVersion, $iCatalogVersion, $ullDbSysId) =
+                    $oDb->info($oFile, optionGet(OPTION_DB_PATH));
+
+                # Check that the stanza backup info is compatible with the current version of the database
+                # If not, an error will be thrown
+                my $iDbHistoryId = $oBackupInfo->check($strDbVersion, $iControlVersion, $iCatalogVersion, $ullDbSysId);
+            }
+        }
+
+        # If the backup and archive checks were successful, then indicate success
+        &log(INFO,
+            "WAL segment ${strWalSegment} successfully stored in the archive at '" .
+            $oFile->pathGet(PATH_BACKUP_ARCHIVE, "$strArchiveId/${strArchiveFile}") . "'");
+    }
+    else
+    {
+        &log(ERROR, $strResultMessage, $iResult);
+        &log(WARN,
+            "WAL segment ${strWalSegment} did not reach the archive:\n" .
+            "HINT: Check the archive_command to ensure that all options are correct (especialy --stanza).\n" .
+            "HINT: Check the PostreSQL server log for errors.");
+    }
+
+    # Return from function and log return values if any
+    return logDebugReturn
+    (
+        $strOperation,
+        {name => 'iResult', value => $iResult, trace => true}
+    );
+
+}
+
 1;
