@@ -58,13 +58,16 @@ sub new
     # Assign function parameters, defaults, and log debug info
     my ($strOperation) = logDebugParam(OP_BACKUP_NEW);
 
+    # Initialize protocol
+    $self->{oProtocol} = protocolGet();
+
     # Initialize default file object
     $self->{oFile} = new pgBackRest::File
     (
         optionGet(OPTION_STANZA),
         optionGet(OPTION_REPO_PATH),
         optionRemoteType(),
-        protocolGet()
+        $self->{oProtocol}
     );
 
     # Initialize variables
@@ -448,6 +451,10 @@ sub processManifest
                     $lManifestSaveCurrent = backupManifestUpdate($oBackupManifest, $$oFileCopy{repo_file}, $bCopied, $lCopySize,
                                                                  $lRepoSize, $strCopyChecksum, $lManifestSaveSize,
                                                                  $lManifestSaveCurrent);
+
+                    # A keep-alive is required here because if there are a large number of resumed files that need to be checksummed
+                    # then the remote might timeout while waiting for a command.
+                    $self->{oProtocol}->keepAlive();
                 }
             }
         }
@@ -468,23 +475,25 @@ sub processManifest
                 $oParam{result_queue} = $oResultQueue;
 
                 # Keep the protocol layer from timing out
-                protocolGet()->keepAlive();
+                $self->{oProtocol}->keepAlive();
 
                 threadGroupRun($iThreadIdx, 'backup', \%oParam);
             }
 
             # Keep the protocol layer from timing out
-            protocolGet()->keepAlive();
+            $self->{oProtocol}->keepAlive();
 
             # Start backup test point
             &log(TEST, TEST_BACKUP_START);
 
             # Complete thread queues
             my $bDone = false;
+            my $bKeepAlive = false;
 
             do
             {
                 $bDone = threadGroupComplete();
+                $bKeepAlive = false;
 
                 # Read the messages that are passed back from the backup threads
                 while (my $oMessage = $oResultQueue->dequeue_nb())
@@ -494,10 +503,18 @@ sub processManifest
                     $lManifestSaveCurrent = backupManifestUpdate($oBackupManifest, $$oMessage{repo_file}, $$oMessage{copied},
                                                                  $$oMessage{size}, $$oMessage{repo_size}, $$oMessage{checksum},
                                                                  $lManifestSaveSize, $lManifestSaveCurrent);
+
+                    # A keep-alive is required inside the loop because a flood of thread messages could prevent the keep-alive
+                    # outside the loop from running in a timely fashion.
+                    $self->{oProtocol}->keepAlive();
+                    $bKeepAlive = true;
                 }
 
-                # Keep the protocol layer from timing out
-                protocolGet()->keepAlive();
+                # This keep-alive only runs if the keep-alive in the loop did not run
+                if (!$bKeepAlive)
+                {
+                    $self->{oProtocol}->keepAlive();
+                }
             }
             while (!$bDone);
         }
@@ -669,7 +686,7 @@ sub process
                                       timestampFormat(undef, $lTimestampStart), optionGet(OPTION_START_FAST));
 
         # Record the archive start location
-        $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_START, undef, $strArchiveStart);
+        $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LSN_START, undef, $strArchiveStart);
         &log(INFO, "archive start: ${strArchiveStart}");
 
         # Get tablespace map
@@ -679,7 +696,7 @@ sub process
         $oDatabaseMap = $self->{oDb}->databaseMapGet();
     }
 
-    # Buid the manifest
+    # Build the manifest
     $oBackupManifest->build($self->{oFile}, optionGet(OPTION_DB_PATH), $oLastManifest, optionGet(OPTION_ONLINE),
                             $oTablespaceMap, $oDatabaseMap);
     &log(TEST, TEST_MANIFEST_BUILD);
@@ -810,8 +827,7 @@ sub process
     {
         ($strArchiveStop, my $strTimestampDbStop, my $oFileHash) = $self->{oDb}->backupStop();
 
-        $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_STOP, undef, $strArchiveStop);
-
+        $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LSN_STOP, undef, $strArchiveStop);
         &log(INFO, 'archive stop: ' . $strArchiveStop);
 
         # Write out files returned from stop backup
@@ -855,7 +871,7 @@ sub process
         # Create the modification time for the archive logs
         my $lModificationTime = time();
 
-        # After the backup has been stopped, need to make a copy of the archive logs need to make the db consistent
+        # After the backup has been stopped, need to make a copy of the archive logs to make the db consistent
         logDebugMisc($strOperation, "retrieve archive logs ${strArchiveStart}:${strArchiveStop}");
         my $oArchive = new pgBackRest::Archive();
         my $strArchiveId = $oArchive->getCheck($self->{oFile});
@@ -863,7 +879,19 @@ sub process
 
         foreach my $strArchive (@stryArchive)
         {
-            my $strArchiveFile = $oArchive->walFileName($self->{oFile}, $strArchiveId, $strArchive, false, 600);
+            my $strArchiveFile =
+                $oArchive->walFileName($self->{oFile}, $strArchiveId, $strArchive, false, optionGet(OPTION_ARCHIVE_TIMEOUT));
+            $strArchive = substr($strArchiveFile, 0, 24);
+
+            if (!$oBackupManifest->test(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_START))
+            {
+                $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_START, undef, $strArchive);
+                $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_STOP, undef, $strArchive);
+            }
+            else
+            {
+                $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_STOP, undef, $strArchive);
+            }
 
             if (optionGet(OPTION_BACKUP_ARCHIVE_COPY))
             {
