@@ -30,14 +30,6 @@ use constant OP_INI                                                 => 'Ini';
 use constant OP_INI_INI_SAVE                                        => OP_INI . "::iniSave";
 use constant OP_INI_SET                                             => OP_INI . "->set";
 
-####################################################################################################################################
-# Version and Format Constants
-####################################################################################################################################
-use constant BACKREST_VERSION                                       => "$VERSION";
-    push @EXPORT, qw(BACKREST_VERSION);
-use constant BACKREST_FORMAT                                        => "$FORMAT";
-    push @EXPORT, qw(BACKREST_FORMAT);
-
 ####################################################################################################################################
 # Boolean constants
 ####################################################################################################################################
@@ -217,7 +209,7 @@ sub iniLoad
 ####################################################################################################################################
 # save
 #
-# Save the manifest.
+# Save the file.
 ####################################################################################################################################
 sub save
 {
@@ -366,7 +358,7 @@ sub hash
     # Remove the old checksum
     $self->remove(INI_SECTION_BACKREST, INI_KEY_CHECKSUM);
 
-    # Caculate the checksum
+    # Calculate the checksum
     my $oChecksumContent = dclone($self->{oContent});
 
     foreach my $strSection (keys(%$oChecksumContent))
