@@ -97,7 +97,7 @@ sub lockAcquire
         # Cannot proceed if a lock is currently held
         if (defined($strCurrentLockType))
         {
-            confess &lock(ASSERT, "${strCurrentLockType} lock is already held");
+            confess &log(ASSERT, "${strCurrentLockType} lock is already held");
         }
 
         # Check if processes are currently stopped
@@ -119,7 +119,7 @@ sub lockAcquire
 
             if (!defined($bFailOnNoLock) || $bFailOnNoLock)
             {
-                confess &log(ERROR, "unable to acquire ${strLockType} lock", ERROR_LOCK_ACQUIRE);
+                confess &log(ERROR, "unable to acquire ${strLockType} lock on file ${strCurrentLockFile}", ERROR_LOCK_ACQUIRE);
             }
         }
         else
@@ -164,7 +164,7 @@ sub lockRelease
         );
 
     # Release if locking is enabled
-    if (!optionTest(OPTION_LOCK) || optionGet(OPTION_LOCK))
+    if (optionValid(OPTION_LOCK))
     {
         # Fail if there is no lock
         if (!defined($strCurrentLockType))
