@@ -94,7 +94,10 @@ my $oPgControlVersionHash =
     {
         201409291 => PG_VERSION_94,
         201510051 => PG_VERSION_95,
-        201605051 => PG_VERSION_96,
+    },
+    960 =>
+    {
+        201607071 => PG_VERSION_96,
     },
 };
 
@@ -627,20 +630,8 @@ sub backupStart
             {name => 'bStartFast'}
         );
 
-    # Get the version from the control file
-    my ($strDbVersion) = $self->info($oFile, $strDbPath);
-
-    # Get version and db path from the database
-    my ($fCompareDbVersion, $strCompareDbPath) = $self->versionGet();
-
-    # Error if the version from the control file and the configured db-path do not match the values obtained from the database
-    if (!($strDbVersion == $fCompareDbVersion && $strDbPath eq $strCompareDbPath))
-    {
-        confess &log(ERROR,
-            "version '${fCompareDbVersion}' and db-path '${strCompareDbPath}' queried from cluster does not match" .
-            " version '${strDbVersion}' and db-path '${strDbPath}' read from '${strDbPath}/" . DB_FILE_PGCONTROL . "'\n" .
-            "HINT: the db-path and db-port settings likely reference different clusters", ERROR_DB_MISMATCH);
-    }
+    # Validate the database configuration
+    $self->configValidate($oFile, $strDbPath);
 
     # Only allow start-fast option for version >= 8.4
     if ($self->{strDbVersion} < PG_VERSION_84 && $bStartFast)
@@ -649,20 +640,6 @@ sub backupStart
         $bStartFast = false;
     }
 
-    # Error if archive_mode = always (support has not been added yet)
-    if ($self->executeSql('show archive_mode') eq 'always')
-    {
-        confess &log(ERROR, "archive_mode=always not supported", ERROR_FEATURE_NOT_SUPPORTED);
-    }
-
-    # Check if archive_command is set
-    my $strArchiveCommand = $self->executeSql('show archive_command');
-
-    if (index($strArchiveCommand, BACKREST_EXE) == -1)
-    {
-        confess &log(ERROR, 'archive_command must contain \'' . BACKREST_EXE . '\'', ERROR_ARCHIVE_COMMAND_INVALID);
-    }
-
     # Acquire the backup advisory lock to make sure that backups are not running from multiple backup servers against the same
     # database cluster.  This lock helps make the stop-auto option safe.
     if (!$self->executeSqlOne('select pg_try_advisory_lock(' . DB_BACKUP_ADVISORY_LOCK . ')'))
@@ -699,12 +676,11 @@ sub backupStart
                "exclusive pg_start_backup() with label \"${strLabel}\": backup begins after " .
                ($bStartFast ? "the requested immediate checkpoint" : "the next regular checkpoint") . " completes");
 
-    my ($strTimestampDbStart, $strArchiveStart) =
-        $self->executeSqlRow("select to_char(current_timestamp, 'YYYY-MM-DD HH24:MI:SS.US TZ'), " .
-                             "pg_xlogfile_name(lsn) from pg_start_backup('${strLabel}'" .
-                             ($bStartFast ? ', true' : '') .
-                             ($self->{strDbVersion} >= PG_VERSION_96 ? (!$bStartFast ? ', false' : '') . ', false' : '') .
-                             ') as lsn');
+    my ($strTimestampDbStart, $strArchiveStart) = $self->executeSqlRow(
+        "select to_char(current_timestamp, 'YYYY-MM-DD HH24:MI:SS.US TZ'), lsn::text" .
+            " from pg_start_backup('${strLabel}'" .
+            ($bStartFast ? ', true' : $self->{strDbVersion} >= PG_VERSION_84 ? ', false' : '') .
+            ($self->{strDbVersion} >= PG_VERSION_96 ? ', false' : '') . ') as lsn');
 
     # Return from function and log return values if any
     return logDebugReturn
@@ -738,7 +714,7 @@ sub backupStop
 
     my ($strTimestampDbStop, $strArchiveStop, $strLabel, $strTablespaceMap) =
         $self->executeSqlRow(
-            "select to_char(clock_timestamp(), 'YYYY-MM-DD HH24:MI:SS.US TZ'), pg_xlogfile_name(lsn), " .
+            "select to_char(clock_timestamp(), 'YYYY-MM-DD HH24:MI:SS.US TZ'), lsn::text, " .
             ($self->{strDbVersion} >= PG_VERSION_96 ? 'labelfile, spcmapfile' : "null as labelfile, null as spcmapfile") .
             ' from pg_stop_backup(' .
             ($self->{strDbVersion} >= PG_VERSION_96 ? 'false)' : ') as lsn'));
@@ -760,4 +736,97 @@ sub backupStop
     );
 }
 
+####################################################################################################################################
+# configValidate
+#
+# Validate the database configuration and archiving.
+####################################################################################################################################
+sub configValidate
+{
+    my $self = shift;
+
+    # Assign function parameters, defaults, and log debug info
+    my
+    (
+        $strOperation,
+        $oFile,
+        $strDbPath
+    ) =
+        logDebugParam
+        (
+            __PACKAGE__ . '->configValidate', \@_,
+            {name => 'oFile'},
+            {name => 'strDbPath'}
+        );
+
+    # Get the version from the control file
+    my ($strDbVersion) = $self->info($oFile, $strDbPath);
+
+    # Get version and db path from the database
+    my ($fCompareDbVersion, $strCompareDbPath) = $self->versionGet();
+
+    # Error if the version from the control file and the configured db-path do not match the values obtained from the database
+    if (!($strDbVersion == $fCompareDbVersion && $strDbPath eq $strCompareDbPath))
+    {
+        confess &log(ERROR,
+            "version '${fCompareDbVersion}' and db-path '${strCompareDbPath}' queried from cluster does not match" .
+            " version '${strDbVersion}' and db-path '${strDbPath}' read from '${strDbPath}/" . DB_FILE_PGCONTROL . "'\n" .
+            "HINT: the db-path and db-port settings likely reference different clusters", ERROR_DB_MISMATCH);
+    }
+
+    # Error if archive_mode = always (support has not been added yet)
+    if (optionGet(OPTION_BACKUP_ARCHIVE_CHECK) && $self->executeSql('show archive_mode') eq 'always')
+    {
+        confess &log(ERROR, "archive_mode=always not supported", ERROR_FEATURE_NOT_SUPPORTED);
+    }
+
+    # Check if archive_command is set
+    if (optionGet(OPTION_BACKUP_ARCHIVE_CHECK))
+    {
+        my $strArchiveCommand = $self->executeSql('show archive_command');
+
+        if (index($strArchiveCommand, BACKREST_EXE) == -1)
+        {
+            confess &log(ERROR,
+                'archive_command \'${strArchiveCommand}\' must contain \'' . BACKREST_EXE . '\'', ERROR_ARCHIVE_COMMAND_INVALID);
+        }
+    }
+
+    return logDebugReturn
+    (
+        $strOperation
+    );
+}
+
+####################################################################################################################################
+# xlogSwitch
+#
+# Forces a switch to the next transaction log in order to archive the current log.
+####################################################################################################################################
+sub xlogSwitch
+{
+    my $self = shift;
+
+    # Assign function parameters, defaults, and log debug info
+    my $strOperation = logDebugParam(__PACKAGE__ . '->xlogSwitch');
+
+    # Create a restore point to ensure current xlog will be archived.  For versions <= 9.0 activity will need to be generated by
+    # the user if there have been no writes since the last xlog switch.
+    if ($self->{strDbVersion} >= PG_VERSION_91)
+    {
+        $self->executeSql("select pg_create_restore_point('pgBackRest Archive Check');");
+    }
+
+    my $strWalFileName = $self->executeSqlRow('select pg_xlogfile_name from pg_xlogfile_name(pg_switch_xlog());');
+
+    &log(INFO, "switch xlog ${strWalFileName}");
+
+    # Return from function and log return values if any
+    return logDebugReturn
+    (
+        $strOperation,
+        {name => 'strXlogFileName', value => $strWalFileName}
+    );
+}
+
 1;
