@@ -52,7 +52,7 @@ sub new
         optionGet(OPTION_STANZA),
         optionGet(OPTION_REPO_PATH),
         optionRemoteType(),
-        protocolGet()
+        protocolGet(true)
     );
 
     # Initialize total archive expired
@@ -314,7 +314,7 @@ sub process
                 {
                     # Get archive info
                     my $oArchive = new pgBackRest::Archive();
-                    my $strArchiveId = $oArchive->getCheck($oFile);
+                    my $strArchiveId = $oArchive->getArchiveId($oFile);
 
                     my $strArchiveExpireMax;
 
