@@ -84,6 +84,10 @@ use constant MANIFEST_KEY_ARCHIVE_STOP                              => 'backup-a
     push @EXPORT, qw(MANIFEST_KEY_ARCHIVE_STOP);
 use constant MANIFEST_KEY_LABEL                                     => 'backup-label';
     push @EXPORT, qw(MANIFEST_KEY_LABEL);
+use constant MANIFEST_KEY_LSN_START                                 => 'backup-lsn-start';
+    push @EXPORT, qw(MANIFEST_KEY_LSN_START);
+use constant MANIFEST_KEY_LSN_STOP                                  => 'backup-lsn-stop';
+    push @EXPORT, qw(MANIFEST_KEY_LSN_STOP);
 use constant MANIFEST_KEY_PRIOR                                     => 'backup-prior';
     push @EXPORT, qw(MANIFEST_KEY_PRIOR);
 use constant MANIFEST_KEY_TIMESTAMP_COPY_START                      => 'backup-timestamp-copy-start';
@@ -160,9 +164,8 @@ use constant DB_PATH_GLOBAL                                         => 'global';
     push @EXPORT, qw(DB_PATH_GLOBAL);
 use constant DB_PATH_PGTBLSPC                                       => 'pg_tblspc';
     push @EXPORT, qw(DB_PATH_PGTBLSPC);
-####################################################################################################################################
-use constant DB_FILE_POSTMASTERPID                                  => 'postmaster.pid';
-    push @EXPORT, qw(DB_FILE_POSTMASTERPID);
+use constant DB_PATH_PGXLOG                                         => 'pg_xlog';
+    push @EXPORT, qw(DB_PATH_PGXLOG);
 
 use constant DB_FILE_BACKUPLABEL                                    => 'backup_label';
     push @EXPORT, qw(DB_FILE_BACKUPLABEL);
@@ -172,6 +175,10 @@ use constant DB_FILE_PGCONTROL                                      => DB_PATH_G
     push @EXPORT, qw(DB_FILE_PGCONTROL);
 use constant DB_FILE_PGVERSION                                      => 'PG_VERSION';
     push @EXPORT, qw(DB_FILE_PGVERSION);
+use constant DB_FILE_POSTMASTEROPTS                                 => 'postmaster.opts';
+    push @EXPORT, qw(DB_FILE_POSTMASTEROPTS);
+use constant DB_FILE_POSTMASTERPID                                  => 'postmaster.pid';
+    push @EXPORT, qw(DB_FILE_POSTMASTERPID);
 use constant DB_FILE_RECOVERYCONF                                   => 'recovery.conf';
     push @EXPORT, qw(DB_FILE_RECOVERYCONF);
 use constant DB_FILE_RECOVERYDONE                                   => 'recovery.done';
@@ -182,6 +189,9 @@ use constant DB_FILE_TABLESPACEMAP                                  => 'tablespa
 ####################################################################################################################################
 # Manifest locations for important files/paths
 ####################################################################################################################################
+use constant MANIFEST_PATH_PGXLOG                                   => MANIFEST_TARGET_PGDATA . '/' . DB_PATH_PGXLOG;
+    push @EXPORT, qw(MANIFEST_PATH_PGXLOG);
+
 use constant MANIFEST_FILE_BACKUPLABEL                              => MANIFEST_TARGET_PGDATA . '/' . DB_FILE_BACKUPLABEL;
     push @EXPORT, qw(MANIFEST_FILE_BACKUPLABEL);
 use constant MANIFEST_FILE_PGCONTROL                                => MANIFEST_TARGET_PGDATA . '/' . DB_FILE_PGCONTROL;
@@ -604,9 +614,10 @@ sub build
         }
 
         # Skip certain files during backup
-        if ($strLevel eq MANIFEST_TARGET_PGDATA &&
-            (($strName =~ /^pg\_xlog\/.*/ && $bOnline) ||           # pg_xlog/ - this will be reconstructed
-             $strName eq DB_FILE_BACKUPLABELOLD ||                  # backup_label.old - old backup labels are not useful
+        if ($strFile =~ ('^' . MANIFEST_PATH_PGXLOG . '.*\/') && $bOnline ||  # pg_xlog/ - this will be reconstructed
+            $strLevel eq MANIFEST_TARGET_PGDATA &&
+            ($strName eq DB_FILE_BACKUPLABELOLD ||                  # backup_label.old - old backup labels are not useful
+             $strName eq DB_FILE_POSTMASTEROPTS ||                  # postmaster.opts - not useful for backup
              $strName eq DB_FILE_POSTMASTERPID ||                   # postmaster.pid - to avoid confusing postgres after restore
              $strName eq DB_FILE_RECOVERYCONF ||                    # recovery.conf - doesn't make sense to backup this file
              $strName eq DB_FILE_RECOVERYDONE))                     # recovery.done - doesn't make sense to backup this file
@@ -657,8 +668,23 @@ sub build
         }
 
         # User and group required for all types
-        $self->set($strSection, $strFile, MANIFEST_SUBKEY_USER, $oManifestHash{name}{$strName}{user});
-        $self->set($strSection, $strFile, MANIFEST_SUBKEY_GROUP, $oManifestHash{name}{$strName}{group});
+        if (defined($oManifestHash{name}{$strName}{user}))
+        {
+            $self->set($strSection, $strFile, MANIFEST_SUBKEY_USER, $oManifestHash{name}{$strName}{user});
+        }
+        else
+        {
+            $self->boolSet($strSection, $strFile, MANIFEST_SUBKEY_USER, false);
+        }
+
+        if (defined($oManifestHash{name}{$strName}{group}))
+        {
+            $self->set($strSection, $strFile, MANIFEST_SUBKEY_GROUP, $oManifestHash{name}{$strName}{group});
+        }
+        else
+        {
+            $self->boolSet($strSection, $strFile, MANIFEST_SUBKEY_GROUP, false);
+        }
 
         # Mode for required file and path type only
         if ($cType eq 'f' || $cType eq 'd')
@@ -791,9 +817,10 @@ sub build
 
         # Record the time when copying will start
         $self->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_TIMESTAMP_COPY_START, undef, $lTimeBegin + ($bOnline ? 1 : 0));
-    }
 
-    $self->buildDefault();
+        # Build default sections
+        $self->buildDefault();
+    }
 
     # Return from function and log return values if any
     return logDebugReturn($strOperation);
@@ -869,15 +896,31 @@ sub fileAdd
         );
 
     # Set manifest values
-    $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_USER,
-               $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_USER));
-    $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_GROUP,
-               $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_GROUP));
-    $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_MODE, '0600');
+    if (!$self->test(MANIFEST_SECTION_TARGET_FILE . ':default', MANIFEST_SUBKEY_USER) ||
+        !$self->test(MANIFEST_SECTION_TARGET_FILE . ':default', MANIFEST_SUBKEY_USER, undef,
+                     $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_USER)))
+    {
+        $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_USER,
+                   $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_USER));
+    }
+
+    if (!$self->test(MANIFEST_SECTION_TARGET_FILE . ':default', MANIFEST_SUBKEY_GROUP) ||
+        !$self->test(MANIFEST_SECTION_TARGET_FILE . ':default', MANIFEST_SUBKEY_GROUP, undef,
+                     $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_GROUP)))
+    {
+        $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_GROUP,
+                   $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_GROUP));
+    }
+
+    if (!$self->test(MANIFEST_SECTION_TARGET_FILE . ':default', MANIFEST_SUBKEY_MODE) ||
+        !$self->test(MANIFEST_SECTION_TARGET_FILE . ':default', MANIFEST_SUBKEY_MODE, undef, '0600'))
+    {
+        $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_MODE, '0600');
+    }
+
     $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_TIMESTAMP, $lModificationTime);
     $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_SIZE, $lSize);
     $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_CHECKSUM, $strChecksum);
-    $self->buildDefault();
 }
 
 ####################################################################################################################################
@@ -897,15 +940,18 @@ sub buildDefault
     {
         foreach my $strSubKey (&MANIFEST_SUBKEY_USER, &MANIFEST_SUBKEY_GROUP, &MANIFEST_SUBKEY_MODE)
         {
+            # Links don't have a mode so skip
+            next if ($strSection eq MANIFEST_SECTION_TARGET_LINK && $strSubKey eq &MANIFEST_SUBKEY_MODE);
+
             my %oDefault;
             my $iSectionTotal = 0;
 
             foreach my $strFile ($self->keys($strSection))
             {
-                my $strValue = $self->get($strSection, $strFile, $strSubKey, false);
-
-                if (defined($strValue))
+                if (!$self->boolTest($strSection, $strFile, $strSubKey, false))
                 {
+                    my $strValue = $self->get($strSection, $strFile, $strSubKey);
+
                     if (defined($oDefault{$strValue}))
                     {
                         $oDefault{$strValue}++;
