@@ -54,6 +54,7 @@ sub new
         $self->{hOut},                              # Output stream
         $self->{hErr},                              # Error stream
         $self->{pId},                               # Process ID
+        $self->{strId},                             # Id for messages
         $self->{iProtocolTimeout},                  # Protocol timeout
         $self->{iBufferMax}                         # Maximum buffer size
     ) =
@@ -64,6 +65,7 @@ sub new
             {name => 'hOut', required => false, trace => true},
             {name => 'hErr', required => false, trace => true},
             {name => 'pId', required => false, trace => true},
+            {name => 'strId', required => false, trace => true},
             {name => 'iProtocolTimeout', trace => true},
             {name => 'iBufferMax', trace => true}
         );
@@ -95,6 +97,7 @@ sub new3
     my
     (
         $strOperation,
+        $strId,
         $strCommand,
         $iProtocolTimeout,                           # Protocol timeout
         $iBufferMax                                  # Maximum buffer Size
@@ -102,6 +105,7 @@ sub new3
         logDebugParam
         (
             OP_IO_PROTOCOL_NEW3, \@_,
+            {name => 'strId', trace => true},
             {name => 'strCommand', trace => true},
             {name => 'iProtocolTimeout', trace => true},
             {name => 'iBufferMax', trace => true}
@@ -117,7 +121,7 @@ sub new3
     return logDebugReturn
     (
         $strOperation,
-        {name => 'self', value => $class->new($hOut, $hIn, $hErr, $pId, $iProtocolTimeout, $iBufferMax)}
+        {name => 'self', value => $class->new($hOut, $hIn, $hErr, $pId, $strId, $iProtocolTimeout, $iBufferMax)}
     );
 }
 
@@ -174,6 +178,7 @@ sub lineRead
     my $iTimeout = shift;
     my $bInRead = shift;
     my $bError = shift;
+    my $bIgnoreEOF = shift;
 
     # If there's already data in the buffer try to find the next linefeed
     my $iLineFeedPos = defined($self->{strBuffer}) ? index($self->{strBuffer}, "\n", $self->{iBufferPos}) : -1;
@@ -253,13 +258,13 @@ sub lineRead
                 }
 
                 # Error on EOF (unless reading from error stream)
-                if ($iBufferRead == 0)
+                if ($iBufferRead == 0 && (!defined($bIgnoreEOF) || !$bIgnoreEOF))
                 {
                     # Check if the remote process exited unexpectedly
-                    $self->waitPid(0);
+                    $self->waitPid();
 
                     # Only error if reading from the input stream
-                    if (defined($bError) && $bError)
+                    if (!defined($bError) || $bError)
                     {
                         confess &log(ERROR, "unexpected EOF", ERROR_FILE_READ);
                     }
@@ -537,8 +542,8 @@ sub waitPid
                     # If the error stream is already closed then we can't fetch the real error
                     if (!defined($self->{hErr}))
                     {
-                        $strError = 'no error captured because stderr is already closed';
-                    }
+                            $strError = 'no error captured because stderr is already closed';
+                        }
                     # Get whatever text we can from the error stream
                     else
                     {
@@ -559,7 +564,11 @@ sub waitPid
 
                         if ($@ || !defined($strError))
                         {
-                            $strError = 'no output from terminated process' . (defined($@) && $@ ne '' ? ": $@" : '');
+                            my $strMessage = $@;
+
+                            $strError =
+                                'no output from terminated process' .
+                                (defined($strMessage) && ${strMessage} ne '' ? ": ${strMessage}" : '');
                         }
                     }
 
@@ -569,11 +578,11 @@ sub waitPid
                     $self->{hErr} = undef;
 
                     # Finally, confess the error
-                    confess &log(ERROR, 'remote process terminated' .
-                                 ($iExitStatus < ERROR_MINIMUM && $iExitStatus > ERROR_MAXIMUM ?
-                                    " (exit status ${iExitStatus}" : '') .
-                                 ": ${strError}",
-                                 $iExitStatus >= ERROR_MINIMUM && $iExitStatus <= ERROR_MAXIMUM ? $iExitStatus : ERROR_HOST_CONNECT);
+                    confess &log(
+                        ERROR, 'remote process terminated on ' . $self->{strId} . ' host' .
+                        ($iExitStatus < ERROR_MINIMUM || $iExitStatus > ERROR_MAXIMUM ? " (exit status ${iExitStatus})" : '') .
+                        ": ${strError}",
+                        $iExitStatus >= ERROR_MINIMUM && $iExitStatus <= ERROR_MAXIMUM ? $iExitStatus : ERROR_HOST_CONNECT);
                 }
 
                 return true;
