@@ -10,17 +10,23 @@ use strict;
 use warnings FATAL => qw(all);
 use Carp qw(confess);
 
-use File::Basename qw(dirname);
-
-use lib dirname($0) . '/../lib';
-use pgBackRest::Db;
-
 use Exporter qw(import);
     our @EXPORT = qw();
 
+use pgBackRest::Common::Log;
+use pgBackRest::Db;
+
 ####################################################################################################################################
 # VM hash keywords
 ####################################################################################################################################
+use constant VM_DB                                                  => 'db';
+    push @EXPORT, qw(VM_DB);
+use constant VM_DB_DOC                                              => 'db-doc';
+    push @EXPORT, qw(VM_DB_DOC);
+use constant VM_DB_MINIMAL                                          => 'db-minimal';
+    push @EXPORT, qw(VM_DB_MINIMAL);
+use constant VM_CONTROL_MASTER                                      => 'control-master';
+    push @EXPORT, qw(VM_CONTROL_MASTER);
 use constant VM_IMAGE                                               => 'image';
     push @EXPORT, qw(VM_IMAGE);
 use constant VM_OS                                                  => 'os';
@@ -29,6 +35,8 @@ use constant VM_OS_BASE                                             => 'os-base'
     push @EXPORT, qw(VM_OS_BASE);
 use constant VM_OS_REPO                                             => 'os-repo';
     push @EXPORT, qw(VM_OS_REPO);
+use constant VMDEF_PGSQL_BIN                                        => 'pgsql-bin';
+    push @EXPORT, qw(VMDEF_PGSQL_BIN);
 
 ####################################################################################################################################
 # Valid OS base List
@@ -72,8 +80,10 @@ my $oyVm =
         &VM_OS_BASE => VM_OS_BASE_RHEL,
         &VM_OS => VM_OS_CENTOS,
         &VM_IMAGE => 'centos:6',
+        &VM_CONTROL_MASTER => false,
+        &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
 
-        db =>
+        &VM_DB =>
         [
             PG_VERSION_90,
             PG_VERSION_91,
@@ -84,11 +94,16 @@ my $oyVm =
             PG_VERSION_96,
         ],
 
-        db_minimal =>
+        &VM_DB_MINIMAL =>
         [
             PG_VERSION_90,
             PG_VERSION_91,
         ],
+
+        &VM_DB_DOC =>
+        [
+            PG_VERSION_94,
+        ],
     },
 
     # CentOS 7
@@ -97,8 +112,10 @@ my $oyVm =
         &VM_OS_BASE => VM_OS_BASE_RHEL,
         &VM_OS => VM_OS_CENTOS,
         &VM_IMAGE => 'centos:7',
+        &VM_CONTROL_MASTER => true,
+        &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
 
-        db =>
+        &VM_DB =>
         [
             PG_VERSION_93,
             PG_VERSION_94,
@@ -106,7 +123,7 @@ my $oyVm =
             PG_VERSION_96,
         ],
 
-        db_minimal =>
+        &VM_DB_MINIMAL =>
         [
             PG_VERSION_95,
             PG_VERSION_96,
@@ -120,8 +137,10 @@ my $oyVm =
         &VM_OS => VM_OS_DEBIAN,
         &VM_OS_REPO => 'jessie',
         &VM_IMAGE => 'debian:8',
+        &VM_CONTROL_MASTER => true,
+        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
 
-        db =>
+        &VM_DB =>
         [
             PG_VERSION_84,
             PG_VERSION_90,
@@ -133,7 +152,7 @@ my $oyVm =
             PG_VERSION_96,
         ],
 
-        db_minimal =>
+        &VM_DB_MINIMAL =>
         [
             PG_VERSION_84,
             PG_VERSION_93,
@@ -147,8 +166,9 @@ my $oyVm =
         &VM_OS => VM_OS_UBUNTU,
         &VM_OS_REPO => 'precise',
         &VM_IMAGE => 'ubuntu:12.04',
+        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
 
-        db =>
+        &VM_DB =>
         [
             PG_VERSION_83,
             PG_VERSION_84,
@@ -161,7 +181,7 @@ my $oyVm =
             PG_VERSION_96,
         ],
 
-        db_minimal =>
+        &VM_DB_MINIMAL =>
         [
             PG_VERSION_83,
         ],
@@ -174,8 +194,10 @@ my $oyVm =
         &VM_OS => VM_OS_UBUNTU,
         &VM_OS_REPO => 'trusty',
         &VM_IMAGE => 'ubuntu:14.04',
+        &VM_CONTROL_MASTER => true,
+        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
 
-        db =>
+        &VM_DB =>
         [
             PG_VERSION_90,
             PG_VERSION_91,
@@ -186,10 +208,15 @@ my $oyVm =
             PG_VERSION_96,
         ],
 
-        db_minimal =>
+        &VM_DB_MINIMAL =>
         [
             PG_VERSION_92,
         ],
+
+        &VM_DB_DOC =>
+        [
+            PG_VERSION_94,
+        ],
     },
 
     # Ubuntu 16.04
@@ -199,8 +226,10 @@ my $oyVm =
         &VM_OS => VM_OS_UBUNTU,
         &VM_OS_REPO => 'xenial',
         &VM_IMAGE => 'ubuntu:16.04',
+        &VM_CONTROL_MASTER => true,
+        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
 
-        db =>
+        &VM_DB =>
         [
             PG_VERSION_91,
             PG_VERSION_92,
@@ -210,7 +239,7 @@ my $oyVm =
             PG_VERSION_96,
         ],
 
-        db_minimal =>
+        &VM_DB_MINIMAL =>
         [
             PG_VERSION_94,
         ],
